@@ -28,6 +28,7 @@
 #include "version.h"
 #include "ukbdcreator.h"
 
+static osso_context_t *osso_context;
 static HildonWindow *window_main;
 static GtkClipboard *clipboard;
 static HildonTextView *view;
@@ -167,7 +168,6 @@ static gchar *file_chooser(gboolean open)
 
 	chooser = hildon_file_chooser_dialog_new(GTK_WINDOW(window_main),
 		open ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE);
-	gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(chooser), "/home/user/MyDocs/ukbdcreator");
 	filter = gtk_file_filter_new();
 	gtk_file_filter_add_pattern(filter, "*.def");
 	gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(chooser), filter);
@@ -250,7 +250,10 @@ static void file_new(void)
 {
 	if (!file_ask_save())
 		return;
-	gtk_text_buffer_set_text(buffer, "", -1);
+
+	if (!read_file("/usr/share/ukbdcreator/template.def"))
+		gtk_text_buffer_set_text(buffer, "", -1);
+
 	set_filename(NULL);
 	is_modified = FALSE;
 	g_free(last_error_msg);
@@ -266,31 +269,28 @@ static gboolean file_quit(void)
 	return FALSE;
 }
 
-static void edit_cut(void)
-{
-	gtk_text_buffer_cut_clipboard(buffer, clipboard, TRUE);
-}
-
-static void edit_copy(void)
-{
-	gtk_text_buffer_copy_clipboard(buffer, clipboard);
-}
-
-static void edit_paste(void)
-{
-	gtk_text_buffer_paste_clipboard(buffer, clipboard, NULL, TRUE);
-}
-
 static void run_about(void)
 {
 	gtk_show_about_dialog(GTK_WINDOW(window_main),
 		"version", UKBD_VERSION,
-		"comments", "Licensed under GPLv2. Please send bug reports and feature requests to jbenc@upir.cz.",
+		"comments", "Licensed under GPLv2. Please send bug reports and feature requests to roman.moravcik@gmail.com.",
 		"copyright", "(c) 2008 Jiri Benc\n(c) 2009 Roman Moravcik",
 		"website", "http://upir.cz/maemo/keyboards/",
 		NULL);
 }
 
+static void run_help(void)
+{
+	osso_rpc_run(osso_context,
+		     "com.nokia.osso_browser",
+		     "/com/nokia/osso_browser",
+		     "com.nokia.osso_browser",
+		     "open_new_window",
+		     NULL,
+		     DBUS_TYPE_STRING, "/usr/share/ukbdcreator/howto.txt",
+		     DBUS_TYPE_INVALID);
+}
+
 static void compile_and_test(void)
 {
 	gchar *buf, *fname, *lang;
@@ -335,6 +335,8 @@ static GtkWidget *main_layout(void)
 	g_signal_connect(G_OBJECT(buffer), "changed", G_CALLBACK(set_modified), NULL);
 	g_signal_connect(G_OBJECT(buffer), "modified-changed", G_CALLBACK(set_modified), NULL);
 
+	file_new();
+
 	return pannable;
 }
 
@@ -364,21 +366,6 @@ static GtkWidget *main_menu(void)
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(file_save_as), NULL);
 	hildon_app_menu_append(HILDON_APP_MENU (menu), GTK_BUTTON(item));
 
-	item = hildon_button_new_with_text (HILDON_SIZE_AUTO,
-					    HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Cut", NULL);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(edit_cut), NULL);
-	hildon_app_menu_append(HILDON_APP_MENU (menu), GTK_BUTTON(item));
-
-	item = hildon_button_new_with_text (HILDON_SIZE_AUTO,
-					    HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Copy", NULL);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(edit_copy), NULL);
-	hildon_app_menu_append(HILDON_APP_MENU (menu), GTK_BUTTON(item));
-
-	item = hildon_button_new_with_text (HILDON_SIZE_AUTO,
-					    HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Paste", NULL);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(edit_paste), NULL);
-	hildon_app_menu_append(HILDON_APP_MENU (menu), GTK_BUTTON(item));
-
 	item = hildon_button_new_with_text (HILDON_SIZE_AUTO,
 					    HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Test layout", NULL);
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(compile_and_test), NULL);
@@ -395,8 +382,8 @@ static GtkWidget *main_menu(void)
 	hildon_app_menu_append(HILDON_APP_MENU (menu), GTK_BUTTON(item));
 
 	item = hildon_button_new_with_text (HILDON_SIZE_AUTO,
-					    HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Fullscreen", NULL);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(toggle_fullscreen), NULL);
+					    HILDON_BUTTON_ARRANGEMENT_VERTICAL, "Help", NULL);
+	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(run_help), NULL);
 	hildon_app_menu_append(HILDON_APP_MENU (menu), GTK_BUTTON(item));
 
 	item = hildon_button_new_with_text (HILDON_SIZE_AUTO,
@@ -417,30 +404,32 @@ static GtkToolbar *main_toolbar(void)
 	gtk_toolbar_set_orientation(bar, GTK_ORIENTATION_HORIZONTAL);
 	gtk_toolbar_set_style(bar, GTK_TOOLBAR_BOTH_HORIZ);
 
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_OPEN);
+	item = gtk_tool_button_new(NULL, NULL);
+	gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "general_toolbar_folder");
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(file_open), NULL);
 	gtk_toolbar_insert(bar, item, -1);
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_SAVE);
+
+	item = gtk_tool_button_new(NULL, NULL);
+	gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "notes_save");
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(file_save), NULL);
 	gtk_toolbar_insert(bar, item, -1);
-	gtk_toolbar_insert(bar, gtk_separator_tool_item_new(), -1);
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_CUT);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(edit_cut), NULL);
-	gtk_toolbar_insert(bar, item, -1);
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_COPY);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(edit_copy), NULL);
-	gtk_toolbar_insert(bar, item, -1);
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_PASTE);
-	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(edit_paste), NULL);
-	gtk_toolbar_insert(bar, item, -1);
-	gtk_toolbar_insert(bar, gtk_separator_tool_item_new(), -1);
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_MEDIA_PLAY);
+
+	item = gtk_tool_button_new(NULL, NULL);
+	gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "camera_playback");
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(compile_and_test), NULL);
 	gtk_toolbar_insert(bar, item, -1);
-	item = gtk_tool_button_new_from_stock(GTK_STOCK_MEDIA_STOP);
+
+	item = gtk_tool_button_new(NULL, NULL);
+	gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "camera_video_stop");
 	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(untest), NULL);
 	gtk_toolbar_insert(bar, item, -1);
 
+	item = gtk_toggle_tool_button_new();
+	gtk_tool_button_set_icon_name(GTK_TOOL_BUTTON(item), "general_fullsize");
+	g_signal_connect(G_OBJECT(item), "clicked", G_CALLBACK(toggle_fullscreen), NULL);
+	gtk_toolbar_insert(bar, item, -1);
+	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(item), FALSE);
+
 	return bar;
 }
 
@@ -452,7 +441,7 @@ int main(int argc, char **argv)
 	program = hildon_program_get_instance();
 	g_set_prgname("ukbdcreator");
 	g_set_application_name("Ukeyboard Creator");
-	osso_initialize("cz.upir.ukbdcreator", UKBD_VERSION, TRUE, NULL);
+	osso_context = osso_initialize("cz.upir.ukbdcreator", UKBD_VERSION, TRUE, NULL);
 	gnome_vfs_init();
 	conf = gconf_client_get_default();
 	gconf_client_add_dir(conf, "/apps/osso/inputmethod/hildon-im-languages",
